@@ -20,7 +20,7 @@ use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -422,7 +422,7 @@ sub get_statements {
                 $model    = $fragment->{model};
                 $info     = $fragment->{info};
 
-                $url      = $info->{hydra_nextPage};
+                $url      = $info->{hydra_next};
                 $iterator = $model->get_statements;
             }
 
