@@ -118,7 +118,7 @@ RDF::Trine::Store::LDF - RDF Store proxy for a Linked Data Fragment endpoint
 
     while (my $s = $iter->next) {
         # $s is a RDF::Trine::VariableBinding
-        print $s . "\n";
+        print $s->value . "\n";
     }
 
 =head1 DESCRIPTION
@@ -137,6 +137,9 @@ Beyond the methods documented below, this class inherits methods from the L<RDF:
 Returns a new RDF::Trine::Store object that will act as a proxy for the Linked Data Fragment
 endpoint accessible via the supplied $url.
 
+Expertimental: more than one url as an ARRAY reference can be provided for an federated 
+query over many LDF endpoints.
+
 =item new_with_config( $hashref )
 
 Returns a new RDF::Trine::Store object configured by a hashref with the url as required key.
